Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2231)

Unified Diff: chrome/browser/ui/webui/options/manage_profile_handler.h

Issue 209393009: In the "create user" overlay, associate avatars with their default names (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: More review comments. Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/options/manage_profile_handler.h
diff --git a/chrome/browser/ui/webui/options/manage_profile_handler.h b/chrome/browser/ui/webui/options/manage_profile_handler.h
index d4286e34b24865ddcb3dc7b28a2b8f50688ef318..73aca880841ef9c2e1e8caf0a163372f42024f58 100644
--- a/chrome/browser/ui/webui/options/manage_profile_handler.h
+++ b/chrome/browser/ui/webui/options/manage_profile_handler.h
@@ -47,8 +47,8 @@ class ManageProfileHandler : public OptionsPageUIHandler,
private:
// Callback for the "requestDefaultProfileIcons" message.
// Sends the array of default profile icon URLs to WebUI.
// |args| is of the form: [ {string} iconURL ]
void RequestDefaultProfileIcons(const base::ListValue* args);
// Callback for the "requestNewProfileDefaults" message.
@@ -56,10 +56,9 @@ class ManageProfileHandler : public OptionsPageUIHandler,
// { "name": profileName, "iconURL": iconURL }
void RequestNewProfileDefaults(const base::ListValue* args);
- // Send all profile icons to the overlay.
- // |iconGrid| is the name of the grid to populate with icons (i.e.
- // "create-profile-icon-grid" or "manage-profile-icon-grid").
- void SendProfileIcons(const base::StringValue& icon_grid);
+ // Send all profile icons and their default names to the overlay.
+ // |mode| is the dialog mode, i.e. "create" or "manage".
+ void SendProfileIconsAndNames(const base::StringValue& mode);
// Sends an object to WebUI of the form:
// profileNames = {
@@ -68,7 +67,7 @@ class ManageProfileHandler : public OptionsPageUIHandler,
// ...
// };
// This is used to detect duplicate profile names.
- void SendProfileNames();
+ void SendExistingProfileNames();
// Callback for the "setProfileIconAndName" message. Sets the name and icon
// of a given profile.
@@ -47,8 +47,8 @@ class ManageProfileHandler : public OptionsPageUIHandler,
private:
// Callback for the "requestDefaultProfileIcons" message.
- // Sends the array of default profile icon URLs to WebUI.
- // |args| is of the form: [ {string} iconURL ]
+ // Sends the array of default profile icon URLs and profile names to WebUI.
+ // First item of |args| is the dialog mode, i.e. "create" or "manage".
void RequestDefaultProfileIcons(const base::ListValue* args);
// Callback for the "requestNewProfileDefaults" message.

Powered by Google App Engine
This is Rietveld 408576698